.. _Tutorials:

*********
Tutorials
*********

The tutorials provide step-by-step introductions to the 
main features of cgatreport.


Tutorials
=========

.. toctree::
   :maxdepth: 2

   Tutorial1.rst 
   Tutorial2.rst 
   Tutorial3.rst 
   Tutorial4.rst 
   Tutorial5.rst
   Tutorial6.rst 
   Tutorial7.rst 
   Tutorial8.rst
   Tutorial9.rst
   Tutorial10.rst
   Tutorial11.rst
   Tutorial12.rst
   Tutorial13.rst
   Tutorial14.rst
   Tutorial15.rst
   Tutorial16.rst

Tutorial results
================

.. toctree::
   :maxdepth: 1
   
   Tutorial1Demo.rst 
   Tutorial2Demo.rst 
   Tutorial3Demo.rst 
   Tutorial4Demo.rst 
   Tutorial5Demo.rst 
   Tutorial6Demo.rst 
